Index: solr/build.xml
===================================================================
--- solr/build.xml	(revision 1087090)
+++ solr/build.xml	(working copy)
@@ -187,6 +187,7 @@
           <fileset dir="contrib">
             <include name="**/lib/**/*.jar"/>
             <include name="**/lucene-libs/**/*.jar"/>
+            <exclude name="**/analysis-extras/lib/**/*icu4j*.jar"/> <!-- extraction/lib/ has this one -->
           </fileset>
          <pathelement location="${dest}/client/solrj"/>
       </path>
Index: lucene/src/java/org/apache/lucene/util/PriorityQueue.java
===================================================================
--- lucene/src/java/org/apache/lucene/util/PriorityQueue.java	(revision 1087090)
+++ lucene/src/java/org/apache/lucene/util/PriorityQueue.java	(working copy)
@@ -21,8 +21,10 @@
  * least element can always be found in constant time.  Put()'s and pop()'s
  * require log(size) time.
  *
- * <p><b>NOTE</b>: This class pre-allocates a full array of
- * length <code>maxSize+1</code>, in {@link #initialize}.
+ * <p><b>NOTE</b>: This class will pre-allocate a full array of
+ * length <code>maxSize+1</code> if instantiated via the
+ * {@link #PriorityQueue(int,boolean)} constructor with
+ * <code>prepopulate</code> set to <code>true</code>.
  * 
  * @lucene.internal
 */
@@ -83,9 +85,10 @@
 
   /**
    * This method can be overridden by extending classes to return a sentinel
-   * object which will be used by {@link #initialize(int)} to fill the queue, so
-   * that the code which uses that queue can always assume it's full and only
-   * change the top without attempting to insert any new object.<br>
+   * object which will be used by the {@link PriorityQueue#PriorityQueue(int,boolean)} 
+   * constructor to fill the queue, so that the code which uses that queue can always
+   * assume it's full and only change the top without attempting to insert any new
+   * object.<br>
    * 
    * Those sentinel values should always compare worse than any non-sentinel
    * value (i.e., {@link #lessThan} should always favor the
@@ -111,11 +114,11 @@
    * </pre>
    * 
    * <b>NOTE:</b> if this method returns a non-null value, it will be called by
-   * {@link #initialize(int)} {@link #size()} times, relying on a new object to
-   * be returned and will not check if it's null again. Therefore you should
-   * ensure any call to this method creates a new instance and behaves
-   * consistently, e.g., it cannot return null if it previously returned
-   * non-null.
+   * the {@link PriorityQueue#PriorityQueue(int,boolean)} constructor 
+   * {@link #size()} times, relying on a new object to be returned and will not
+   * check if it's null again. Therefore you should ensure any call to this
+   * method creates a new instance and behaves consistently, e.g., it cannot
+   * return null if it previously returned non-null.
    * 
    * @return the sentinel object to use to pre-populate the queue, or null if
    *         sentinel objects are not supported.
Index: lucene/build.xml
===================================================================
--- lucene/build.xml	(revision 1087090)
+++ lucene/build.xml	(working copy)
@@ -195,6 +195,16 @@
   <target name="javadocs-all" description="Generate javadoc for core and contrib classes" depends="build-contrib">
   	<sequential>
       <mkdir dir="${javadoc.dir}/all"/>
+
+      <path id="javadoc.classpath">
+        <path refid="classpath"/>
+        <pathelement location="${ant.home}/lib/ant.jar"/>
+        <fileset dir=".">
+          <include name="**/lib/*.jar"/>
+        </fileset>
+        <pathelement location="${common.dir}/../modules/analysis/build/common/lucene-analyzers-common-${version}.jar"/>
+      </path>
+
       <invoke-javadoc
         destdir="${javadoc.dir}/all">
         <sources>

Index: lucene/src/java/org/apache/lucene/index/FieldInfos.java
===================================================================
--- lucene/src/java/org/apache/lucene/index/FieldInfos.java	(revision 1087090)
+++ lucene/src/java/org/apache/lucene/index/FieldInfos.java	(working copy)
@@ -28,6 +28,7 @@
 import java.util.TreeMap;
 import java.util.Map.Entry;
 
+import org.apache.lucene.index.SegmentCodecs; // Required for Java 1.5 javadocs
 import org.apache.lucene.index.SegmentCodecs.SegmentCodecsBuilder;
 import org.apache.lucene.index.codecs.CodecProvider;
 import org.apache.lucene.store.Directory;
@@ -218,12 +219,13 @@
 
   /**
    * Creates a new {@link FieldInfos} instance with a private
-   * {@link FieldNumberBiMap} and a default {@link SegmentCodecsBuilder}
+   * {@link org.apache.lucene.index.FieldInfos.FieldNumberBiMap} and a default {@link SegmentCodecsBuilder}
    * initialized with {@link CodecProvider#getDefault()}.
    * <p>
    * Note: this ctor should not be used during indexing use
    * {@link FieldInfos#FieldInfos(FieldInfos)} or
-   * {@link FieldInfos#FieldInfos(FieldNumberBiMap)} instead.
+   * {@link FieldInfos#FieldInfos(FieldNumberBiMap,org.apache.lucene.index.SegmentCodecs.SegmentCodecsBuilder)}
+   * instead.
    */
   public FieldInfos() {
     this(new FieldNumberBiMap(), SegmentCodecsBuilder.create(CodecProvider.getDefault()));
@@ -552,9 +554,10 @@
   
   /**
    * Returns <code>true</code> iff this instance is not backed by a
    * {@link FieldNumberBiMap}. Instances read from a directory via
    * {@link FieldInfos#FieldInfos(Directory, String)} will always be read-only
    * since no {@link FieldNumberBiMap} is supplied, otherwise <code>false</code>.
    */
   public final boolean isReadOnly() {
     return globalFieldNumbers == null;
@@ -552,9 +554,10 @@
   /**
    * Returns <code>true</code> iff this instance is not backed by a
-   * {@link FieldNumberBiMap}. Instances read from a directory via
+   * {@link org.apache.lucene.index.FieldInfos.FieldNumberBiMap}. Instances read from a directory via
    * {@link FieldInfos#FieldInfos(Directory, String)} will always be read-only
@@ -552,9 +554,10 @@
    * {@link FieldInfos#FieldInfos(Directory, String)} will always be read-only
-   * since no {@link FieldNumberBiMap} is supplied, otherwise <code>false</code>.
+   * since no {@link org.apache.lucene.index.FieldInfos.FieldNumberBiMap} is supplied, otherwise 
+   * <code>false</code>.
    */
   public final boolean isReadOnly() {